#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['openweather_api']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.24.0', 'iso3166>=1.0.1']

extras_require = \
{'test': ['pytest', 'pytest-cov', 'pytest-sugar']}

setup(name='openweather_api',
      version='0.1.0',
      description='OpenWeather API client',
      author='Alessandro De Noia',
      author_email='alessandro.denoia@gmail.com',
      url='https://github.com/sdonk/openweather-api-client',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
